@@ -23,7 +23,7 @@
 
 /**
  * SECTION:gstinfo
- * @short_description: Debugging and logging facillities
+ * @short_description: Debugging and logging facilities
  * @see_also: #GstConfig, #Gst for command line parameters
  * and environment variables that affect the debugging output.
  *
@@ -77,7 +77,7 @@
  * subsystem was compiled out, #GST_DISABLE_GST_DEBUG is defined in
  * &lt;gst/gst.h&gt;,
  * so you can check that before doing your trick.
- * Disabling the debugging subsystem will give you a slight (read: unnoticable)
+ * Disabling the debugging subsystem will give you a slight (read: unnoticeable)
  * speed increase and will reduce the size of your compiled code. The GStreamer
  * library itself becomes around 10% smaller.
  *
@@ -104,6 +104,7 @@
 #  include <process.h>          /* getpid on win32 */
 #endif
 #include <string.h>             /* G_VA_COPY */
+
 #include "gst_private.h"
 #include "gstutils.h"
 #include "gstsegment.h"
@@ -114,8 +115,12 @@
 
 /* underscore is to prevent conflict with GST_CAT_DEBUG define */
 GST_DEBUG_CATEGORY_STATIC (_GST_CAT_DEBUG);
-/* time of initialization, so we get useful debugging output times */
-static GstClockTime start_time;
+
+/* time of initialization, so we get useful debugging output times
+ * FIXME: we use this in gstdebugutils.c, what about a function + macro to
+ * get the running time: GST_DEBUG_RUNNING_TIME
+ */
+GstClockTime _priv_gst_info_start_time;
 
 #if 0
 #if defined __sgi__
@@ -232,7 +237,7 @@ GstDebugCategory *GST_CAT_QOS = NULL;
 
 /* FIXME: export this? */
 gboolean
-__gst_in_valgrind (void)
+_priv_gst_in_valgrind (void)
 {
   static enum
   {
@@ -272,14 +277,11 @@ __gst_in_valgrind (void)
 void
 _gst_debug_init (void)
 {
-  GTimeVal current;
-
-  gst_atomic_int_set (&__default_level, GST_LEVEL_DEFAULT);
-  gst_atomic_int_set (&__use_color, 1);
+  g_atomic_int_set (&__default_level, GST_LEVEL_DEFAULT);
+  g_atomic_int_set (&__use_color, 1);
 
   /* get time we started for debugging messages */
-  g_get_current_time (&current);
-  start_time = GST_TIMEVAL_TO_TIME (current);
+  _priv_gst_info_start_time = gst_util_get_timestamp ();
 
 #ifdef HAVE_PRINTF_EXTENSION
   register_printf_function (GST_PTR_FORMAT[0], _gst_info_printf_extension_ptr,
@@ -356,7 +358,7 @@ _gst_debug_init (void)
 
 
   /* print out the valgrind message if we're in valgrind */
-  __gst_in_valgrind ();
+  _priv_gst_in_valgrind ();
 }
 
 /* we can't do this further above, because we initialize the GST_CAT_DEFAULT struct */
@@ -410,11 +412,24 @@ gst_debug_log_valist (GstDebugCategory * category, GstDebugLevel level,
   LogFuncEntry *entry;
   GSList *handler;
 
+#ifdef _MSC_VER
+  gchar *file_basename;
+#endif
+
   g_return_if_fail (category != NULL);
   g_return_if_fail (file != NULL);
   g_return_if_fail (function != NULL);
   g_return_if_fail (format != NULL);
 
+#ifdef _MSC_VER
+  /*
+   * The predefined macro __FILE__ is always the exact path given to the
+   * compiler with MSVC, which may or may not be the basename.  We work
+   * around it at runtime to improve the readability.
+   */
+  file = file_basename = g_path_get_basename (file);
+#endif
+
   message.message = NULL;
   message.format = format;
   G_VA_COPY (message.arguments, args);
@@ -428,6 +443,10 @@ gst_debug_log_valist (GstDebugCategory * category, GstDebugLevel level,
   }
   g_free (message.message);
   va_end (message.arguments);
+
+#ifdef _MSC_VER
+  g_free (file_basename);
+#endif
 }
 
 /**
@@ -571,15 +590,14 @@ gchar *
 gst_debug_construct_term_color (guint colorinfo)
 {
   GString *color;
-  gchar *ret;
 
   color = g_string_new ("\033[00");
 
   if (colorinfo & GST_DEBUG_BOLD) {
-    g_string_append (color, ";01");
+    g_string_append_len (color, ";01", 3);
   }
   if (colorinfo & GST_DEBUG_UNDERLINE) {
-    g_string_append (color, ";04");
+    g_string_append_len (color, ";04", 3);
   }
   if (colorinfo & GST_DEBUG_FG_MASK) {
     g_string_append_printf (color, ";3%1d", colorinfo & GST_DEBUG_FG_MASK);
@@ -588,11 +606,9 @@ gst_debug_construct_term_color (guint colorinfo)
     g_string_append_printf (color, ";4%1d",
         (colorinfo & GST_DEBUG_BG_MASK) >> 4);
   }
-  g_string_append (color, "m");
+  g_string_append_c (color, 'm');
 
-  ret = color->str;
-  g_string_free (color, FALSE);
-  return ret;
+  return g_string_free (color, FALSE);
 }
 
 /**
@@ -624,7 +640,6 @@ gst_debug_log_default (GstDebugCategory * category, GstDebugLevel level,
   gchar pidcolor[10];
   const gchar *levelcolor;
   gint pid;
-  GTimeVal now;
   GstClockTime elapsed;
   gboolean free_color = TRUE;
   gboolean free_obj = TRUE;
@@ -664,23 +679,28 @@ gst_debug_log_default (GstDebugCategory * category, GstDebugLevel level,
     free_obj = FALSE;
   }
 
-  g_get_current_time (&now);
-  elapsed = GST_TIMEVAL_TO_TIME (now) - start_time;
-
-  /*
-     g_printerr ("%s (%p - %" GST_TIME_FORMAT ") %s%20s%s(%s%5d%s) %s%s(%d):%s:%s%s %s\n",
-     gst_debug_level_get_name (level), g_thread_self (),
-     GST_TIME_ARGS (elapsed), color,
-     gst_debug_category_get_name (category), clear, pidcolor, pid, clear,
-     color, file, line, function, obj, clear, gst_debug_message_get (message));
-   */
+  elapsed = GST_CLOCK_DIFF (_priv_gst_info_start_time,
+      gst_util_get_timestamp ());
 
+#if defined (GLIB_SIZEOF_VOID_P) && GLIB_SIZEOF_VOID_P == 8
+  /* width of %p varies depending on actual value of pointer, which can make
+   * output unevenly aligned if multiple threads are involved, hence the %14p
+   * (should really be %18p, but %14p seems a good compromise between too many
+   * white spaces and likely unalignment on my system) */
   g_printerr ("%" GST_TIME_FORMAT
-      " %s%5d%s %p %s%s%s %s%20s %s:%d:%s:%s%s %s\n", GST_TIME_ARGS (elapsed),
+      " %s%5d%s %14p %s%s%s %s%20s %s:%d:%s:%s%s %s\n", GST_TIME_ARGS (elapsed),
       pidcolor, pid, clear, g_thread_self (), levelcolor,
       gst_debug_level_get_name (level), clear, color,
       gst_debug_category_get_name (category), file, line, function, obj, clear,
       gst_debug_message_get (message));
+#else
+  g_printerr ("%" GST_TIME_FORMAT
+      " %s%5d%s %10p %s%s%s %s%20s %s:%d:%s:%s%s %s\n", GST_TIME_ARGS (elapsed),
+      pidcolor, pid, clear, g_thread_self (), levelcolor,
+      gst_debug_level_get_name (level), clear, color,
+      gst_debug_category_get_name (category), file, line, function, obj, clear,
+      gst_debug_message_get (message));
+#endif
 
   if (free_color)
     g_free (color);
@@ -692,7 +712,7 @@ gst_debug_log_default (GstDebugCategory * category, GstDebugLevel level,
  * gst_debug_level_get_name:
  * @level: the level to get the name for
  *
- * Get the string trepresentation of a debugging level
+ * Get the string representation of a debugging level
  *
  * Returns: the name
  */
@@ -779,6 +799,8 @@ gst_debug_remove_with_compare_func (GCompareFunc func, gpointer data)
   new = __log_functions;
   while ((found = g_slist_find_custom (new, data, func))) {
     if (new == __log_functions) {
+      /* make a copy when we have the first hit, so that we modify the copy and
+       * make that the new list later */
       new = g_slist_copy (new);
       continue;
     }
@@ -797,7 +819,7 @@ gst_debug_remove_with_compare_func (GCompareFunc func, gpointer data)
  * gst_debug_remove_log_function:
  * @func: the log function to remove
  *
- * Removes all registrered instances of the given logging functions.
+ * Removes all registered instances of the given logging functions.
  *
  * Returns: How many instances of the function were removed
  */
@@ -821,7 +843,7 @@ gst_debug_remove_log_function (GstLogFunction func)
  * gst_debug_remove_log_function_by_data:
  * @data: user data of the log function to remove
  *
- * Removes all registrered instances of log functions with the given user data.
+ * Removes all registered instances of log functions with the given user data.
  *
  * Returns: How many instances of the function were removed
  */
@@ -849,7 +871,7 @@ gst_debug_remove_log_function_by_data (gpointer data)
 void
 gst_debug_set_colored (gboolean colored)
 {
-  gst_atomic_int_set (&__use_color, colored ? 1 : 0);
+  g_atomic_int_set (&__use_color, colored ? 1 : 0);
 }
 
 /**
@@ -908,7 +930,7 @@ gst_debug_is_active (void)
 void
 gst_debug_set_default_threshold (GstDebugLevel level)
 {
-  gst_atomic_int_set (&__default_level, level);
+  g_atomic_int_set (&__default_level, level);
   gst_debug_reset_all_thresholds ();
 }
 
@@ -1031,7 +1053,8 @@ gst_debug_unset_threshold_for_name (const gchar * name)
 }
 
 GstDebugCategory *
-_gst_debug_category_new (gchar * name, guint color, gchar * description)
+_gst_debug_category_new (const gchar * name, guint color,
+    const gchar * description)
 {
   GstDebugCategory *cat;
 
@@ -1045,7 +1068,7 @@ _gst_debug_category_new (gchar * name, guint color, gchar * description)
   } else {
     cat->description = g_strdup ("no description");
   }
-  gst_atomic_int_set (&cat->threshold, 0);
+  g_atomic_int_set (&cat->threshold, 0);
   gst_debug_reset_threshold (cat, NULL);
 
   /* add to category list */
@@ -1103,7 +1126,7 @@ gst_debug_category_set_threshold (GstDebugCategory * category,
     __gst_debug_min = level;
   }
 
-  gst_atomic_int_set (&category->threshold, level);
+  g_atomic_int_set (&category->threshold, level);
 }
 
 /**
@@ -1126,7 +1149,7 @@ gst_debug_category_reset_threshold (GstDebugCategory * category)
  * gst_debug_category_get_threshold:
  * @category: a #GstDebugCategory to get threshold of.
  *
- * Returns the threshold of a #GstCategory.
+ * Returns the threshold of a #GstDebugCategory.
  *
  * Returns: the #GstDebugLevel that is used as threshold.
  */
@@ -1215,7 +1238,7 @@ _gst_debug_nameof_funcptr (GstDebugFuncPtr ptr)
   gchar *ptrname;
 
 #ifdef HAVE_DLADDR
-  Dl_info dlinfo;
+  Dl_info dl_info;
 #endif
 
   if (G_UNLIKELY (func == NULL))
@@ -1233,8 +1256,8 @@ _gst_debug_nameof_funcptr (GstDebugFuncPtr ptr)
   /* we need to create an entry in the hash table for this one so we don't leak
    * the name */
 #ifdef HAVE_DLADDR
-  if (dladdr ((gpointer) func, &dlinfo) && dlinfo.dli_sname) {
-    gchar *name = g_strdup (dlinfo.dli_sname);
+  if (dladdr ((gpointer) func, &dl_info) && dl_info.dli_sname) {
+    gchar *name = g_strdup (dl_info.dli_sname);
 
     _gst_debug_register_funcptr (func, name);
     return name;
@@ -1263,6 +1286,8 @@ _gst_debug_register_funcptr (GstDebugFuncPtr func, const gchar * ptrname)
   g_static_mutex_unlock (&__dbg_functions_mutex);
 }
 
+/*** PRINTF EXTENSIONS ********************************************************/
+
 #ifdef HAVE_PRINTF_EXTENSION
 static int
 _gst_info_printf_extension_ptr (FILE * stream, const struct printf_info *info,
@@ -1326,7 +1351,7 @@ gst_debug_remove_log_function_by_data (gpointer data)
 }
 
 gboolean
-__gst_in_valgrind (void)
+_priv_gst_in_valgrind (void)
 {
   return FALSE;
 }
@@ -1373,7 +1398,7 @@ __cyg_profile_func_exit (void *this_fn, void *call_site)
 /**
  * gst_debug_print_stack_trace:
  *
- * If GST_ENABLE_FUNC_INSTRUMENTATION is defined a stacktracke is available for
+ * If GST_ENABLE_FUNC_INSTRUMENTATION is defined a stacktrace is available for
  * gstreamer code, which can be printed with this function.
  */
 void
@@ -1400,4 +1425,4 @@ gst_debug_print_stack_trace (void)
   /* nothing because it's compiled out */
 }
 
-#endif /* GST_ENABLE_FUNC_INTSTRUMENTATION */
+#endif /* GST_ENABLE_FUNC_INSTRUMENTATION */
