@@ -91,7 +91,7 @@ struct _GstBaseSink {
   /*< private >*/
   union {
     struct {
-      /* segment used for clipping incomming buffers */
+      /* segment used for clipping incoming buffers */
       GstSegment    *clip_segment;
       /* max amount of time a buffer can be late, -1 no limit. */
       gint64	     max_lateness;
@@ -104,26 +104,36 @@ struct _GstBaseSink {
 
 /**
  * GstBaseSinkClass:
+ * @parent_class: Element parent class
  * @get_caps: Called to get sink pad caps from the subclass
  * @set_caps: Notify subclass of changed caps
  * @buffer_alloc: Subclasses can override to perform custom buffer allocations
  * @get_times: Called to get the start and end times for synchronising
- *             the passed buffer to the clock
+ *     the passed buffer to the clock
  * @start: Start processing. Ideal for opening resources in the subclass
  * @stop: Stop processing. Subclasses should use this to close resources.
  * @unlock: Unlock any pending access to the resource. Subclasses should
- *          unblock any blocked function ASAP
+ *     unblock any blocked function ASAP
+ * @unlock_stop: Clear the previous unlock request. Subclasses should clear
+ *     any state they set during unlock(), such as clearing command queues. 
  * @event: Override this to handle events arriving on the sink pad
  * @preroll: Called to present the preroll buffer if desired
  * @render: Called when a buffer should be presented or output, at the
- *          correct moment if the #GstBaseSink has been set to sync to
- *          the clock.
+ *     correct moment if the #GstBaseSink has been set to sync to the clock.
  * @async_play: Subclasses should override this when they need to perform
- *              special processing when changing to the PLAYING state
- *              asynchronously.  Called with the OBJECT_LOCK held.
+ *     special processing when changing to the PLAYING state asynchronously.
+ *     Called with the OBJECT_LOCK held.
+ * @activate_pull: Subclasses should override this when they can provide an
+ *     alternate method of spawning a thread to drive the pipeline in pull mode.
+ *     Should start or stop the pulling thread, depending on the value of the
+ *     "active" argument. Called after actually activating the sink pad in pull
+ *     mode. The default implementation starts a task on the sink pad.
+ * @fixate: Only useful in pull mode, this vmethod will be called in response to
+ *     gst_pad_fixate_caps() being called on the sink pad. Implement if you have
+ *     ideas about what should be the default values for the caps you support.
  *
  * Subclasses can override any of the available virtual methods or not, as
- * needed. At the minimum, the render method should be overridden to
+ * needed. At the minimum, the @render method should be overridden to
  * output/present buffers.
  */
 struct _GstBaseSinkClass {
@@ -160,23 +170,58 @@ struct _GstBaseSinkClass {
   /* when an ASYNC state change to PLAYING happens */ /* with LOCK */
   GstStateChangeReturn (*async_play)   (GstBaseSink *sink);
 
+  /* start or stop a pulling thread */
+  gboolean	(*activate_pull)(GstBaseSink *sink, gboolean active);
+
+  /* fixate sink caps during pull-mode negotiation */
+  void		(*fixate)	(GstBaseSink *sink, GstCaps *caps);
+
+  /* Clear a previously indicated unlock request not that unlocking is 
+   * complete. Sub-classes should clear any command queue or indicator they
+   * set during unlock */
+  gboolean      (*unlock_stop)       (GstBaseSink *sink);
+
   /*< private >*/
-  gpointer       _gst_reserved[GST_PADDING_LARGE-1];
+  gpointer       _gst_reserved[GST_PADDING_LARGE-4];
 };
 
 GType gst_base_sink_get_type(void);
 
 GstFlowReturn	gst_base_sink_wait_preroll 	(GstBaseSink *sink);
 
+/* synchronizing against the clock */
 void		gst_base_sink_set_sync 		(GstBaseSink *sink, gboolean sync);
 gboolean	gst_base_sink_get_sync 		(GstBaseSink *sink);
 
+/* dropping late buffers */
 void		gst_base_sink_set_max_lateness 	(GstBaseSink *sink, gint64 max_lateness);
 gint64		gst_base_sink_get_max_lateness 	(GstBaseSink *sink);
 
+/* performing QoS */
 void		gst_base_sink_set_qos_enabled 	(GstBaseSink *sink, gboolean enabled);
 gboolean	gst_base_sink_is_qos_enabled 	(GstBaseSink *sink);
 
+/* doing async state changes */
+void		gst_base_sink_set_async_enabled	(GstBaseSink *sink, gboolean enabled);
+gboolean	gst_base_sink_is_async_enabled 	(GstBaseSink *sink);
+
+/* tuning synchronisation */
+void		gst_base_sink_set_ts_offset	(GstBaseSink *sink, GstClockTimeDiff offset);
+GstClockTimeDiff gst_base_sink_get_ts_offset 	(GstBaseSink *sink);
+
+/* last buffer */
+GstBuffer *	gst_base_sink_get_last_buffer	(GstBaseSink *sink);
+
+/* latency */
+gboolean	gst_base_sink_query_latency 	(GstBaseSink *sink, gboolean *live, gboolean *upstream_live,
+						 GstClockTime *min_latency, GstClockTime *max_latency);
+GstClockTime	gst_base_sink_get_latency 	(GstBaseSink *sink);
+
+GstClockReturn  gst_base_sink_wait_clock        (GstBaseSink * basesink, GstClockTime time,
+                                                 GstClockTimeDiff * jitter);
+GstFlowReturn   gst_base_sink_wait_eos          (GstBaseSink *sink, GstClockTime time,
+                                                 GstClockTimeDiff *jitter);
+
 G_END_DECLS
 
 #endif /* __GST_BASE_SINK_H__ */
