@@ -28,6 +28,10 @@
  * inside the 'check' directories of various GStreamer packages.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "gstcheck.h"
 
 GST_DEBUG_CATEGORY (check_debug);
@@ -82,6 +86,88 @@ static void gst_check_log_critical_func
     _gst_check_raised_warning = TRUE;
 }
 
+#if defined(G_OS_UNIX) && defined(HAVE_EXECINFO_H)
+#include <signal.h>
+#include <execinfo.h>
+#include <unistd.h>
+
+static struct sigaction oldaction_segv;
+static struct sigaction oldaction_ill;
+static struct sigaction oldaction_bus;
+static struct sigaction oldaction_abrt;
+static gboolean _gst_check_fault_handler_is_setup;      /* FALSE */
+
+static void
+_gst_check_fault_handler_restore (void)
+{
+  if (!_gst_check_fault_handler_is_setup)
+    return;
+
+  _gst_check_fault_handler_is_setup = FALSE;
+
+  sigaction (SIGSEGV, &oldaction_segv, NULL);
+  sigaction (SIGILL, &oldaction_ill, NULL);
+  sigaction (SIGBUS, &oldaction_bus, NULL);
+  sigaction (SIGABRT, &oldaction_abrt, NULL);
+}
+
+static void
+_gst_check_fault_handler_sighandler (int signum)
+{
+  void *bt_arr[100];
+  int num;
+  char *signame;
+
+  /* We need to restore the fault handler or we'll keep getting it */
+  _gst_check_fault_handler_restore ();
+
+  switch (signum) {
+    case SIGSEGV:
+      signame = "SIGSEGV";
+      break;
+    case SIGILL:
+      signame = "SIGILL";
+      break;
+    case SIGBUS:
+      signame = "SIGBUS";
+      break;
+    case SIGABRT:
+      signame = "SIGABRT";
+      break;
+    default:
+      signame = "Unknown Signal";
+      break;
+  }
+
+  fprintf (stderr, "\nERROR: Caught signal '%s' while running test.\n",
+      signame);
+
+  fprintf (stderr, "Backtrace:\n");
+
+  if ((num = backtrace ((void **) bt_arr, G_N_ELEMENTS (bt_arr))))
+    backtrace_symbols_fd (bt_arr, num, STDERR_FILENO);
+}
+
+static void
+_gst_check_fault_handler_setup (void)
+{
+  struct sigaction action;
+
+  if (_gst_check_fault_handler_is_setup)
+    return;
+
+  _gst_check_fault_handler_is_setup = TRUE;
+
+  memset (&action, 0, sizeof (action));
+  action.sa_handler = _gst_check_fault_handler_sighandler;
+
+  sigaction (SIGSEGV, &action, &oldaction_segv);
+  sigaction (SIGILL, &action, &oldaction_ill);
+  sigaction (SIGBUS, &action, &oldaction_bus);
+  sigaction (SIGABRT, &action, &oldaction_abrt);
+}
+#endif /* G_OS_UNIX && HAVE_EXECINFO_H */
+
 /* initialize GStreamer testing */
 void
 gst_check_init (int *argc, char **argv[])
@@ -106,6 +192,10 @@ gst_check_init (int *argc, char **argv[])
 
   check_cond = g_cond_new ();
   check_mutex = g_mutex_new ();
+
+#if defined(G_OS_UNIX) && defined(HAVE_EXECINFO_H)
+  _gst_check_fault_handler_setup ();
+#endif
 }
 
 /* message checking */
@@ -180,7 +270,7 @@ gst_check_setup_src_pad (GstElement * element,
   fail_if (srcpad == NULL, "Could not create a srcpad");
   ASSERT_OBJECT_REFCOUNT (srcpad, "srcpad", 1);
 
-  sinkpad = gst_element_get_pad (element, "sink");
+  sinkpad = gst_element_get_static_pad (element, "sink");
   fail_if (sinkpad == NULL, "Could not get sink pad from %s",
       GST_ELEMENT_NAME (element));
   ASSERT_OBJECT_REFCOUNT (sinkpad, "sinkpad", 2);
@@ -200,7 +290,7 @@ gst_check_teardown_src_pad (GstElement * element)
   GstPad *srcpad, *sinkpad;
 
   /* clean up floating src pad */
-  sinkpad = gst_element_get_pad (element, "sink");
+  sinkpad = gst_element_get_static_pad (element, "sink");
   ASSERT_OBJECT_REFCOUNT (sinkpad, "sinkpad", 2);
   srcpad = gst_pad_get_peer (sinkpad);
 
@@ -233,7 +323,7 @@ gst_check_setup_sink_pad (GstElement * element, GstStaticPadTemplate * template,
   GST_DEBUG_OBJECT (element, "setting up receiving pad %p", sinkpad);
   fail_if (sinkpad == NULL, "Could not create a sinkpad");
 
-  srcpad = gst_element_get_pad (element, "src");
+  srcpad = gst_element_get_static_pad (element, "src");
   fail_if (srcpad == NULL, "Could not get source pad from %s",
       GST_ELEMENT_NAME (element));
   if (caps)
@@ -256,7 +346,7 @@ gst_check_teardown_sink_pad (GstElement * element)
   GstPad *srcpad, *sinkpad;
 
   /* clean up floating sink pad */
-  srcpad = gst_element_get_pad (element, "src");
+  srcpad = gst_element_get_static_pad (element, "src");
   sinkpad = gst_pad_get_peer (srcpad);
 
   gst_pad_unlink (srcpad, sinkpad);
@@ -294,7 +384,6 @@ gst_check_drop_buffers (void)
 
 /**
  * gst_check_caps_equal:
- *
  * @caps1: first caps to compare
  * @caps2: second caps to compare
  *
@@ -358,7 +447,7 @@ gst_check_element_push_buffer_list (const gchar * element_name,
   src_caps = GST_BUFFER_CAPS (buffer);
   src_pad = gst_pad_new (NULL, GST_PAD_SRC);
   gst_pad_set_caps (src_pad, src_caps);
-  pad_peer = gst_element_get_pad (element, "sink");
+  pad_peer = gst_element_get_static_pad (element, "sink");
   fail_if (pad_peer == NULL);
   fail_unless (gst_pad_link (src_pad, pad_peer) == GST_PAD_LINK_OK,
       "Could not link source and %s sink pads", GST_ELEMENT_NAME (element));
@@ -384,7 +473,7 @@ gst_check_element_push_buffer_list (const gchar * element_name,
     fail_unless (GST_IS_PAD (sink_pad));
     gst_pad_set_caps (sink_pad, sink_caps);
     /* get the peer pad */
-    pad_peer = gst_element_get_pad (element, "src");
+    pad_peer = gst_element_get_static_pad (element, "src");
     fail_unless (gst_pad_link (pad_peer, sink_pad) == GST_PAD_LINK_OK,
         "Could not link sink and %s source pads", GST_ELEMENT_NAME (element));
     gst_object_unref (pad_peer);
@@ -443,7 +532,7 @@ gst_check_element_push_buffer_list (const gchar * element_name,
 
 /**
  * gst_check_element_push_buffer:
- * @element: name of the element that needs to be created
+ * @element_name: name of the element that needs to be created
  * @buffer_in: push this buffer to the element
  * @buffer_out: compare the result with this buffer
  *
