@@ -44,9 +44,6 @@
 #include "gstinterpolationcontrolsource.h"
 #include "gstinterpolationcontrolsourceprivate.h"
 
-extern GstInterpolateMethod *interpolation_methods[];
-extern guint num_interpolation_methods;
-
 static void gst_interpolation_control_source_init (GstInterpolationControlSource
     * self);
 static void
@@ -71,7 +68,7 @@ gst_control_point_free (GstControlPoint * cp)
   g_return_if_fail (cp);
 
   g_value_unset (&cp->value);
-  g_free (cp);
+  g_slice_free (GstControlPoint, cp);
 }
 
 static void
@@ -133,7 +130,8 @@ gboolean
   gboolean ret = TRUE;
   GstControlSource *csource = GST_CONTROL_SOURCE (self);
 
-  if (mode >= num_interpolation_methods || interpolation_methods[mode] == NULL) {
+  if (mode >= priv_gst_num_interpolation_methods
+      || priv_gst_interpolation_methods[mode] == NULL) {
     GST_WARNING ("interpolation mode %d invalid or not implemented yet", mode);
     return FALSE;
   }
@@ -151,68 +149,68 @@ gboolean
   g_mutex_lock (self->lock);
   switch (self->priv->base) {
     case G_TYPE_INT:
-      csource->get_value = interpolation_methods[mode]->get_int;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_int;
       csource->get_value_array =
-          interpolation_methods[mode]->get_int_value_array;
+          priv_gst_interpolation_methods[mode]->get_int_value_array;
       break;
     case G_TYPE_UINT:{
-      csource->get_value = interpolation_methods[mode]->get_uint;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_uint;
       csource->get_value_array =
-          interpolation_methods[mode]->get_uint_value_array;
+          priv_gst_interpolation_methods[mode]->get_uint_value_array;
       break;
     }
     case G_TYPE_LONG:{
-      csource->get_value = interpolation_methods[mode]->get_long;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_long;
       csource->get_value_array =
-          interpolation_methods[mode]->get_long_value_array;
+          priv_gst_interpolation_methods[mode]->get_long_value_array;
       break;
     }
     case G_TYPE_ULONG:{
-      csource->get_value = interpolation_methods[mode]->get_ulong;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_ulong;
       csource->get_value_array =
-          interpolation_methods[mode]->get_ulong_value_array;
+          priv_gst_interpolation_methods[mode]->get_ulong_value_array;
       break;
     }
     case G_TYPE_INT64:{
-      csource->get_value = interpolation_methods[mode]->get_int64;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_int64;
       csource->get_value_array =
-          interpolation_methods[mode]->get_int64_value_array;
+          priv_gst_interpolation_methods[mode]->get_int64_value_array;
       break;
     }
     case G_TYPE_UINT64:{
-      csource->get_value = interpolation_methods[mode]->get_uint64;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_uint64;
       csource->get_value_array =
-          interpolation_methods[mode]->get_uint64_value_array;
+          priv_gst_interpolation_methods[mode]->get_uint64_value_array;
       break;
     }
     case G_TYPE_FLOAT:{
-      csource->get_value = interpolation_methods[mode]->get_float;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_float;
       csource->get_value_array =
-          interpolation_methods[mode]->get_float_value_array;
+          priv_gst_interpolation_methods[mode]->get_float_value_array;
       break;
     }
     case G_TYPE_DOUBLE:{
-      csource->get_value = interpolation_methods[mode]->get_double;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_double;
       csource->get_value_array =
-          interpolation_methods[mode]->get_double_value_array;
+          priv_gst_interpolation_methods[mode]->get_double_value_array;
       break;
     }
     case G_TYPE_BOOLEAN:{
-      csource->get_value = interpolation_methods[mode]->get_boolean;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_boolean;
       csource->get_value_array =
-          interpolation_methods[mode]->get_boolean_value_array;
+          priv_gst_interpolation_methods[mode]->get_boolean_value_array;
       break;
     }
     case G_TYPE_ENUM:{
-      csource->get_value = interpolation_methods[mode]->get_enum;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_enum;
       csource->get_value_array =
-          interpolation_methods[mode]->get_enum_value_array;
+          priv_gst_interpolation_methods[mode]->get_enum_value_array;
       break;
     }
     case G_TYPE_STRING:{
-      csource->get_value = interpolation_methods[mode]->get_string;
+      csource->get_value = priv_gst_interpolation_methods[mode]->get_string;
       csource->get_value_array =
-          interpolation_methods[mode]->get_string_value_array;
+          priv_gst_interpolation_methods[mode]->get_string_value_array;
       break;
     }
     default:
@@ -432,7 +430,7 @@ gst_interpolation_control_source_set_internal (GstInterpolationControlSource *
     g_value_copy (value, &cp->value);
   } else {
     /* create a new GstControlPoint */
-    cp = g_new0 (GstControlPoint, 1);
+    cp = g_slice_new0 (GstControlPoint);
     cp->timestamp = timestamp;
     g_value_init (&cp->value, self->priv->type);
     g_value_copy (value, &cp->value);
