@@ -299,10 +299,10 @@ GST_START_TEST (test_message_state_changed_children)
    * base_src is blocked in the push and has an extra refcount.
    * base_sink_chain has taken a refcount on the sink, and is blocked on
    * preroll */
-  ASSERT_OBJECT_REFCOUNT (src, "src", 3);
+  ASSERT_OBJECT_REFCOUNT (src, "src", 2);
   /* refcount can be 4 if the bin is still processing the async_done message of
    * the sink. */
-  ASSERT_OBJECT_REFCOUNT_BETWEEN (sink, "sink", 3, 4);
+  ASSERT_OBJECT_REFCOUNT_BETWEEN (sink, "sink", 2, 3);
   /* 2 or 3 is valid, because the pipeline might still be posting 
    * its state_change message */
   ASSERT_OBJECT_REFCOUNT_BETWEEN (pipeline, "pipeline", 2, 3);
@@ -312,8 +312,8 @@ GST_START_TEST (test_message_state_changed_children)
   fail_if ((gst_bus_pop (bus)) != NULL);
 
   ASSERT_OBJECT_REFCOUNT (bus, "bus", 2);
-  ASSERT_OBJECT_REFCOUNT (src, "src", 2);
-  ASSERT_OBJECT_REFCOUNT (sink, "sink", 2);
+  ASSERT_OBJECT_REFCOUNT (src, "src", 1);
+  ASSERT_OBJECT_REFCOUNT (sink, "sink", 1);
   ASSERT_OBJECT_REFCOUNT (pipeline, "pipeline", 1);
 
   /* change state to PLAYING, spawning three messages */
@@ -456,9 +456,9 @@ GST_START_TEST (test_add_linked)
   sink = gst_element_factory_make ("fakesink", NULL);
   fail_if (sink == NULL, "Could not create fakesink");
 
-  srcpad = gst_element_get_pad (src, "src");
+  srcpad = gst_element_get_static_pad (src, "src");
   fail_unless (srcpad != NULL);
-  sinkpad = gst_element_get_pad (sink, "sink");
+  sinkpad = gst_element_get_static_pad (sink, "sink");
   fail_unless (sinkpad != NULL);
 
   fail_unless (gst_pad_link (srcpad, sinkpad) == GST_PAD_LINK_OK);
@@ -834,7 +834,64 @@ GST_START_TEST (test_children_state_change_order_two_sink)
 
 GST_END_TEST;
 
-Suite *
+GST_START_TEST (test_iterate_sorted)
+{
+  GstElement *src, *tee, *identity, *sink1, *sink2, *pipeline, *bin;
+  GstIterator *it;
+  gpointer elem;
+
+  pipeline = gst_pipeline_new (NULL);
+  fail_unless (pipeline != NULL, "Could not create pipeline");
+
+  bin = gst_bin_new (NULL);
+  fail_unless (bin != NULL, "Could not create bin");
+
+  src = gst_element_factory_make ("fakesrc", NULL);
+  fail_if (src == NULL, "Could not create fakesrc");
+
+  tee = gst_element_factory_make ("tee", NULL);
+  fail_if (tee == NULL, "Could not create tee");
+
+  sink1 = gst_element_factory_make ("fakesink", NULL);
+  fail_if (sink1 == NULL, "Could not create fakesink1");
+
+  gst_bin_add_many (GST_BIN (bin), src, tee, sink1, NULL);
+
+  fail_unless (gst_element_link (src, tee) == TRUE);
+  fail_unless (gst_element_link (tee, sink1) == TRUE);
+
+  identity = gst_element_factory_make ("identity", NULL);
+  fail_if (identity == NULL, "Could not create identity");
+
+  sink2 = gst_element_factory_make ("fakesink", NULL);
+  fail_if (sink2 == NULL, "Could not create fakesink2");
+
+  gst_bin_add_many (GST_BIN (pipeline), bin, identity, sink2, NULL);
+
+  fail_unless (gst_element_link (tee, identity) == TRUE);
+  fail_unless (gst_element_link (identity, sink2) == TRUE);
+
+  it = gst_bin_iterate_sorted (GST_BIN (pipeline));
+  fail_unless (gst_iterator_next (it, &elem) == GST_ITERATOR_OK);
+  fail_unless (elem == sink2);
+  gst_object_unref (elem);
+
+  fail_unless (gst_iterator_next (it, &elem) == GST_ITERATOR_OK);
+  fail_unless (elem == identity);
+  gst_object_unref (elem);
+
+  fail_unless (gst_iterator_next (it, &elem) == GST_ITERATOR_OK);
+  fail_unless (elem == bin);
+  gst_object_unref (elem);
+
+  gst_iterator_free (it);
+
+  gst_object_unref (pipeline);
+}
+
+GST_END_TEST;
+
+static Suite *
 gst_bin_suite (void)
 {
   Suite *s = suite_create ("GstBin");
@@ -853,6 +910,7 @@ gst_bin_suite (void)
   tcase_add_test (tc_chain, test_watch_for_state_change);
   tcase_add_test (tc_chain, test_add_linked);
   tcase_add_test (tc_chain, test_add_self);
+  tcase_add_test (tc_chain, test_iterate_sorted);
 
   return s;
 }
